#!/bin/bash
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 14-03-2007
# source location  : http://inadyn.ina-tech.net/
# url              : http://inadyn.ina-tech.net/inadyn.v1.96.2.zip

NAME=inadyn
VERSION=1.96.2
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=zip

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf $NAME
  if [ -f $NAME.v$VERSION.$EXTENSION ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$NAME.v$VERSION.$EXTENSION ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$NAME.v$VERSION.$EXTENSION $TMP/
	  echo "done"
  else
	  wget -c http://inadyn.ina-tech.net/$NAME.v$VERSION.$EXTENSION
  fi
  unzip $NAME.v$VERSION.$EXTENSION

cd $NAME

# Configure:
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

# Build and install:
make $numjobs || exit 1

# Relocate
mkdir -p $PKG/usr/sbin
mkdir -p $PKG/usr/man/man{5,8}
mkdir -p $PKG/etc/rc.d
cp bin/linux/inadyn $PKG/usr/sbin
cp man/inadyn.8 $PKG/usr/man/man8
cp man/inadyn.conf.5 $PKG/usr/man/man5

cat <<"EOF" > $PKG/etc/rc.d/rc.inadyn.new
#!/bin/bash
#
# Start/Stop inadyn daemon
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 14-03-2007
LOGFILE=/var/log/inadyn
INPUTFILE=/etc/inadyn.conf

start(){
	pid=`pidof inadyn`
	if [ -z $pid ]; then
		inadyn --log_file $LOGFILE --background --input_file $INPUTFILE
	else
		echo "inadyn is already running"
	fi
}

stop(){
	pid=`pidof inadyn`
	if [ -z $pid ]; then
		echo "inadyn isn't running"
	else
		kill -9 $pid >/dev/null 2>&1
	fi
}
restart()
{
	stop
	sleep 2
	start
}

case "$1" in
'start')
	start
	;;
'stop')
	stop
	;;
'restart')
	restart
	;;
*)
  echo "Usage $(basename $0): start|stop|restart"
esac
EOF
chmod +x $PKG/etc/rc.d/rc.inadyn.new

cat <<"EOF" > $PKG/etc/inadyn.conf.new
update_period 600 #Check for a new IP every 600 seconds

username test
password test

alias mydomain.com
EOF

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
	find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
	find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="doc/* readme.html"
cd $TMP/$NAME
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install
cat <<"EOF" > $PKG/install/doinst.sh
config() {
  NEW="$1.new"
  OLD="$1"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}
config etc/rc.d/rc.inadyn
config etc/inadyn.conf
EOF
chmod +x $PKG/install/doinst.sh


#    |-----handy-ruler------------------------------------------------------|
echo "$NAME: $NAME (Simple DYNAMIC DNS client) 
$NAME:
$NAME: INADYN is a dynamic DNS client. That is, it maintains the IP address
$NAME: of a host name. It periodically checks whether the IP address stored
$NAME: by the DNS server is the real current address of the machine that is
$NAME: running INADYN.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:" > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
echo "" > $NAME-$VERSION-$ARCH-$BUILD.dep

